<?php

require_once 'dd.constant.php';

abstract class BaseDD {
	
	//define constant value
	const BUTTON_DESIGN_NORMAL = 'Normal';
	const BUTTON_DESIGN_COMPACT = 'Compact';
	const VOTE_URL = 'VOTE_URL'; 
	const VOTE_TITLE = 'VOTE_TITLE';
	const VOTE_BUTTON_DESIGN = 'VOTE_BUTTON_DESIGN';
	const DEFAULT_APPEND_TYPE = 'none';
	
    // define properties
    var $name; //name of the vote button
    var $baseURL; // vote button URL
    var $buttonDesign; //vote button design
    var $wp_options; // contains wordpress option value, in array
    
    var $finalURL; //final URL for display, after constructs
    
    var $option_append_type;
	var $option_button_design;
	var $option_button_weight;
	
	var $button_weight_value;
	var $normalButtonWH;
	var $compactButtonWH;
	
    /**
     * Construct the default value for digg digg 
     * @param $name name of the vote site
     * @param $baseURL URL for the vote button 
     */
    function BaseDD($name, $baseURL) {
    	$this->name = $name;
    	$this->baseURL = $baseURL;
    	$this->initWPOptions();
    }
    
    /**
     * Construct the wordpress options value
     */
    private function initWPOptions() {
    	$this->wp_options = array();
    	$this->wp_options[$this->option_append_type] = self::DEFAULT_APPEND_TYPE;
    	$this->wp_options[$this->option_button_design] = self::BUTTON_DESIGN_NORMAL;
    	$this->wp_options[$this->option_button_weight] = $this->button_weight_value;
    }
    
	/*
     * return the button order value
     */
    public function get_button_weight(){
    	return $this->wp_options[$this->option_button_weight];
    }
    
    /*
     * return the append type value
     */
    public function get_append_type(){
    	return $this->wp_options[$this->option_append_type];
    }
    
	/*
     * return the button design value
     */
    public function get_button_design(){
    	return $this->wp_options[$this->option_button_design];
    }
    
    /**
     * Return the button design layout 
     * @param $button button design, normal or compact
     * @return button design
     */
    public function getButtonDesign($button){
    	
    	$result ='';
    	
    	if($button==self::BUTTON_DESIGN_NORMAL){
    		$result = $this->normalButtonWH;
    	}else if ($button==self::BUTTON_DESIGN_COMPACT){
    		$result = $this->compactButtonWH;
    	}else{
    		$result = $this->normalButtonWH;
    	}
    	
    	return $result;
    }
	
    /**
     * @param $url post link
     * @param $title post title
     * @param $button button design
     * 
     */
    public function construstURL($url, $title,$button){
    	$result = '';
    	
    	$result = str_replace(self::VOTE_BUTTON_DESIGN,$this->getButtonDesign($button),$this->baseURL);
    	$result = str_replace(self::VOTE_TITLE,$title,$result);
    	$result = str_replace(self::VOTE_URL,$url,$result);
    	
    	$this->finalURL = $result;
    }
    
}

//Digg.com properties and methods
class DD_Digg extends BaseDD{
	
	//constant value
	const NAME = "Digg";
	const BASEURL = "<iframe src='http://digg.com/api/diggthis.php?w=new&amp;u=VOTE_URL&amp;t=VOTE_TITLE&amp;s=VOTE_BUTTON_DESIGN frameborder='0' scrolling='no'></iframe>";
	const OPTION_APPEND_TYPE = "dd_digg_appendType";
	const OPTION_BUTTON_DESIGN = "dd_digg_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_digg_button_weight";
	const NORMAL_BUTTON_WH = "normal' height='80' width='52'";
	const COMPACT_BUTTON_WH = "compact' height='18' width='120'";
	const DEFAULT_BUTTON_WEIGHT = "100";
	
	//constructor
    public function DD_Digg() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//Reddit.com properties and methods
class DD_Reddit extends BaseDD{
	
	//constant value
	const NAME = "Reddit";
	const BASEURL = "<iframe src='http://www.reddit.com/button_content?newwindow=1&amp;url=VOTE_URL&amp;title=VOTE_TITLE&amp;t=VOTE_BUTTON_DESIGN frameborder='0' scrolling='no'></iframe>";
	const OPTION_APPEND_TYPE = "dd_reddit_appendType";
	const OPTION_BUTTON_DESIGN = "dd_reddit_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_reddit_button_weight";
	const NORMAL_BUTTON_WH = "2' height='80' width='52'";
	const COMPACT_BUTTON_WH = "1' height='18' width='120'";
	const DEFAULT_BUTTON_WEIGHT = "95";

	//constructor
    public function DD_Reddit() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//dzone.com properties and methods
class DD_Dzone extends BaseDD{
	
	//constant value
	const NAME = "Dzone";
	const BASEURL = "<iframe src='http://widgets.dzone.com/links/widgets/zoneit.html?url=VOTE_URL&amp;title=VOTE_TITLE&amp;t=VOTE_BUTTON_DESIGN frameborder='0' scrolling='no'></iframe>";
	const OPTION_APPEND_TYPE = "dd_dzone_appendType";
	const OPTION_BUTTON_DESIGN = "dd_dzone_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_dzone_button_weight";
	const NORMAL_BUTTON_WH = "1' height='80' width='52'";
	const COMPACT_BUTTON_WH = "2' height='18' width='120'";
	const DEFAULT_BUTTON_WEIGHT = "90";
	          
	//constructor
    public function DD_Dzone() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}


//buzz.yahoo.com properties and methods
class DD_YBuzz extends BaseDD{
	
	//constant value
	const NAME = "YBuzz";
	const BASEURL = "<script type='text/javascript'><!--yahooBuzzArticleHeadline=VOTE_TITLE;//--></script><script type='text/javascript' src='http://d.yimg.com/ds/badge2.js' badgetype='VOTE_BUTTON_DESIGN'></script>";
	const OPTION_APPEND_TYPE = "dd_ybuzz_appendType";
	const OPTION_BUTTON_DESIGN = "dd_ybuzz_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_ybuzz_button_weight";
	const NORMAL_BUTTON_WH = "square";
	const COMPACT_BUTTON_WH = "small-votes";
	const DEFAULT_BUTTON_WEIGHT = "85";
	      
	//constructor
    public function DD_YBuzz() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//tweetmeme.com properties and methods
class DD_Twitter extends BaseDD{
	
	//constant value
	const NAME = "Twitter";
	const BASEURL ="<iframe src='http://api.tweetmeme.com/button.js?url=VOTE_URL&amp;source=VOTE_SOURCE&amp;style=VOTE_BUTTON_DESIGN frameborder='0' scrolling='no'></iframe>";
	const OPTION_APPEND_TYPE = "dd_twitter_appendType";
	const OPTION_BUTTON_DESIGN = "dd_twitter_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_twitter_button_weight";
	const NORMAL_BUTTON_WH = "normal' height='61' width='50'";
	const COMPACT_BUTTON_WH = "compact' height='20' width='90'";
    const DEFAULT_BUTTON_WEIGHT = "80";
          
	const VOTE_SOURCE = "VOTE_SOURCE";
	
	//constructor
    public function DD_Twitter() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
        
    } 
    
    //override the base method to construct the source 
	public function construstURL($url, $source,$button){
    	$result = '';
    	
    	$realButtonLayout =$this->getButtonDesign($button);
    	$result = str_replace(parent::VOTE_BUTTON_DESIGN,$realButtonLayout,$this->baseURL);
    	$result = str_replace(self::VOTE_SOURCE,$source,$result);
    	$result = str_replace(parent::VOTE_URL,$url,$result);
    	
    	$this->finalURL = $result;
    }
    
}

//fbshare.com properties and methods
class DD_FbShare extends BaseDD{
	
	//constant value
	const NAME = "Facebook";
	const BASEURL ="<script type='text/javascript'> var fbShare = {url: 'VOTE_URL',size:'VOTE_BUTTON_DESIGN'}</script> <script type='text/javascript' src='http://widgets.fbshare.me/files/fbshare.js'></script>";
	const OPTION_APPEND_TYPE = "dd_fbshare_appendType";
	const OPTION_BUTTON_DESIGN = "dd_fbshare_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_fbshare_button_weight";
	const NORMAL_BUTTON_WH = "large";
	const COMPACT_BUTTON_WH = "small";
	const DEFAULT_BUTTON_WEIGHT = "75";
	
	//constructor
    public function DD_FbShare() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}


//polladium.com properties and methods
class DD_Polladium extends BaseDD{
	
	//constant value
	const NAME = "Polladium";
	const BASEURL = "<script type='text/javascript' src='http://www.polladium.com/web_services/poll-this/poll-this.js?t=VOTE_TITLE&amp;u=VOTE_URL&amp;type=VOTE_BUTTON_DESIGN'></script>";
	const OPTION_APPEND_TYPE = "dd_polladium_appendType";
	const OPTION_BUTTON_DESIGN = "dd_polladium_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_polladium_button_weight";
	const NORMAL_BUTTON_WH = "normal";
	const COMPACT_BUTTON_WH = "compact";
	const DEFAULT_BUTTON_WEIGHT = "70";
	
	//constructor
    public function DD_Polladium() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
}

//stumbleupon.com properties and methods
class DD_StumbleUpon extends BaseDD{
	
	//constant value
	const NAME = "Stumbleupon";
	const BASEURL = "<a href='http://www.stumbleupon.com/submit?url=VOTE_URL&amp;title=VOTE_TITLE'>VOTE_BUTTON_DESIGN</a>";
	const OPTION_APPEND_TYPE = "dd_stumbleupon_appendType";
	const OPTION_BUTTON_DESIGN = "dd_stumbleupon_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_stumbleupon_button_weight";
	const DEFAULT_BUTTON_WEIGHT = "65";
	
	//constructor
    public function DD_StumbleUpon() {
    	
    	$normalbutton = "<img src='" . DD_PLUGPATH . "image/stumbleupon.png' width='56' height='56' alt='Stumbleupon' />";
		
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = $normalbutton;
		$this->compactButtonWH = $normalbutton;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
}


//delicious.com properties and methods
class DD_Delicious extends BaseDD{
	
	//constant value
	const NAME = "Delicious";
	const BASEURL = "<a href='http://delicious.com/save' onclick=\"window.open('http://delicious.com/save?v=5&amp;noui&amp;jump=close&amp;url='+encodeURIComponent('VOTE_URL')+'&amp;title='+encodeURIComponent('VOTE_TITLE'),'delicious', 'toolbar=no,width=550,height=550'); return false;\">VOTE_BUTTON_DESIGN</a>";
	const OPTION_APPEND_TYPE = "dd_delicious_appendType";
	const OPTION_BUTTON_DESIGN = "dd_delicious_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_delicious_button_weight";
	const DEFAULT_BUTTON_WEIGHT = "60";
	

	//constructor
    public function DD_Delicious() {
    	
    	$normalbutton = "<img src='" . DD_PLUGPATH . "image/delicious.png' width='54' height='54' alt='Delicious' />";
		
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = $normalbutton;
		$this->compactButtonWH = $normalbutton;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
}

//sphinn.com properties and methods
class DD_Sphinn extends BaseDD{
	
	//constant value
	const NAME = "Sphinn";
	const BASEURL ="<script type='text/javascript'> submit_url = \"VOTE_URL\"; </script> <script type='text/javascript' src='http://sphinn.com/evb/button.php'></script>";
	const OPTION_APPEND_TYPE = "dd_sphinn_appendType";
	const OPTION_BUTTON_DESIGN = "dd_sphinn_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_sphinn_button_weight";
	const NORMAL_BUTTON_WH = "large";
	const COMPACT_BUTTON_WH = "small";
	const DEFAULT_BUTTON_WEIGHT = "55";
	
	//constructor
    public function DD_Sphinn() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//post comments properties and methods
class DD_Comments extends BaseDD{
	
	//#comments
	//constant value
	const NAME = "Comments";
	const BASEURL = "<div id=\"dd_comments\"><a class=\"clcount\" href=VOTE_URL><span class=\"ctotal\">COMMENTS_COUNT</span><br /><span class=\"cmsg\">Comments</span></a><a class=\"clink\" href=VOTE_URL></a></div>";
	
	const OPTION_APPEND_TYPE = "dd_comments_appendType";
	const OPTION_BUTTON_DESIGN = "dd_comments_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_comments_button_weight";
	const DEFAULT_BUTTON_WEIGHT = "50";
	
	const COMMENTS_COUNT = "COMMENTS_COUNT";
	const COMMENTS_FLOW = "COMMENTS_FLOW";
	const COMMENTS_DETAIL_ID = "#comments";
	const COMMENTS_RESPONSE_ID = "#respond";

	//constructor
    public function DD_Comments() {
    	
    	$normalbutton = "";
		
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = $normalbutton;
		$this->compactButtonWH = $normalbutton;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
    
	//override the base method to construct the source 
	public function construstURL($url,$count){
    	$result = '';
    	
    	if($count!='0'){
    		$url = $url . self::COMMENTS_DETAIL_ID;
    	}else{
    		$url = $url . self::COMMENTS_RESPONSE_ID;
    	}
    	
    	$result = str_replace(self::VOTE_URL,$url,$this->baseURL);
    	$result = str_replace(self::COMMENTS_COUNT,$count,$result);
    	
    	$this->finalURL = $result;
    }
    
}


//Google Buzz properties and methods
class DD_GBuzz extends BaseDD{
	
	//constant value
	const NAME = "Google buzz";
	const BASEURL = "<a href='http://www.google.com/reader/link?url=VOTE_URL&amp;title=VOTE_TITLE&amp;srcURL=VOTE_SOURCE'>VOTE_BUTTON_DESIGN</a>";
	const OPTION_APPEND_TYPE = "dd_gbuzz_appendType";
	const OPTION_BUTTON_DESIGN = "dd_gbuzz_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_gbuzz_button_weight";
	const DEFAULT_BUTTON_WEIGHT = "45";
	const VOTE_SOURCE = "VOTE_SOURCE";
	
	//constructor
    public function DD_GBuzz() {
    	
    	$normalbutton = "<img src='" . DD_PLUGPATH . "image/google-buzz.png' width='50' height='58' alt='Google Buzz' />";
    	$compactbutton = "<img src='" . DD_PLUGPATH . "image/google-buzz-compact.png' alt='Google Buzz' />";
		
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = $normalbutton;
		$this->compactButtonWH = $compactbutton;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
    
	//override the base method to construct the source 
	public function construstURL($url, $title, $source, $button){
    	$result = '';
    	
    	$realButtonLayout =$this->getButtonDesign($button);
    	$result = str_replace(parent::VOTE_BUTTON_DESIGN,$realButtonLayout,$this->baseURL);
    	$result = str_replace(self::VOTE_SOURCE,$source,$result);
    	$result = str_replace(parent::VOTE_TITLE,$title,$result);
    	$result = str_replace(parent::VOTE_URL,$url,$result);
    	
    	$this->finalURL = $result;
    }
    
}

?>